
.. _dut_tcad:

TCAD simulation DuTs
=======================

TCAD (Technology Computer-Aided Design) simulators often simulate just single devices and small volumes. As they allow to obtain special data from inside the device, they are different from circuit simulators.


DutTcad submodules
-------------------------------

.. toctree::
    :maxdepth: 1
    :glob:

    interfaces/*

TCAD class
------------------------------

.. automodule:: DMT.core.dut_tcad
    :members:
    :undoc-members:
    :show-inheritance:
